# linear_regression/regression.py

import numpy as np

class SimpleLinearRegression:
    def __init__(self):
        self.slope = None
        self.intercept = None

    def fit(self, X, y):
        n = len(X)
        self.slope = (n * np.dot(X, y) - np.sum(X) * np.sum(y)) / (n * np.dot(X, X) - np.sum(X) ** 2)
        self.intercept = np.mean(y) - self.slope * np.mean(X)

    def predict(self, X):
        return self.intercept + self.slope * X



from setuptools import setup, find_packages

setup(
    name='MAOuladlinear_regression',
    version='1.0.0',
    author='Mohamed lamine OULAD SAID',
    author_email='mohamedamineouledsaid10@gmail.com',
    packages=find_packages(),  # Trouver automatiquement les packages
    url='http://pypi.python.org/pypi/MAOuladlinear_regression/',
    license='LICENSE.txt',
    description='An awesome package that does something',
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    install_requires=[],  # Si vous avez des dépendances, vous pouvez les lister ici, sinon laissez vide
)
